# ConnectorCheckOutcome


## Enum

* `SUCCEEDED` (value: `'succeeded'`)

* `FAILED` (value: `'failed'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


